@@ -1,2 +1,2 @@
 from .movies import H5SequenceSet, MovieFileTreeDataset
-from .statics import StaticImageSet, FileTreeDataset
+from .statics import FileTreeDataset, StaticImageSet
