@@ -1,26 +1,25 @@
+import logging
 import warnings
-from collections import OrderedDict, Iterable
+from collections import Iterable, OrderedDict
 from functools import partial
 
-from torch import nn
 import torch
 import torchvision
+from torch import nn
 
-from .base import Core
 from ... import regularizers
-from ..conv import DepthSeparableConv2d
-from ..squeeze_excitation import SqueezeExcitationBlock
-from ..attention import AttentionConv
-from ..affine import Bias2DLayer, Scale2DLayer
 from ..activations import AdaptiveELU
+from ..affine import Bias2DLayer, Scale2DLayer
+from ..attention import AttentionConv
+from ..conv import DepthSeparableConv2d
 from ..hermite import (
     HermiteConv2D,
     RotationEquivariantBatchNorm2D,
     RotationEquivariantBias2DLayer,
     RotationEquivariantScale2DLayer,
 )
-
-import logging
+from ..squeeze_excitation import SqueezeExcitationBlock
+from .base import Core
 
 logger = logging.getLogger(__name__)
 
@@ -148,14 +147,21 @@ class Stacked2dCore(Core, nn.Module):
         if depth_separable:
             self.conv_layer_name = "ds_conv"
             self.ConvLayer = DepthSeparableConv2d
+            self.ignore_group_sparsity = True
         elif attention_conv:
             # TODO: check if name attention_conv is backwards compatible
             self.conv_layer_name = "attention_conv"
             self.ConvLayer = self.AttentionConvWrapper
+            self.ignore_group_sparsity = True
         else:
             self.conv_layer_name = "conv"
             self.ConvLayer = nn.Conv2d
+            self.ignore_group_sparsity = False
 
+        if (self.ignore_group_sparsity) and (gamma_hidden > 0):
+            warnings.warn(
+                "group sparsity can not be calculated for the requested conv type. Hidden channels will not be regularized and gamma_hidden is ignored."
+            )
         self.set_batchnorm_type()
         self.features = nn.Sequential()
         self.add_first_layer()
@@ -182,7 +188,9 @@ class Stacked2dCore(Core, nn.Module):
                     layer["scale"] = self.scale_layer_cls(self.hidden_channels)
 
     def add_activation(self, layer):
-        if (self.num_layers > 1 or self.final_nonlinearity) and not self.linear:
+        if self.linear:
+            return
+        if len(self.features) < self.num_layers - 1 or self.final_nonlinearity:
             layer["nonlin"] = AdaptiveELU(self.elu_xshift, self.elu_yshift)
 
     def add_first_layer(self):
@@ -249,6 +257,9 @@ class Stacked2dCore(Core, nn.Module):
         Sparsity regularization on the filters of all the conv2d layers except the first one.
         """
         ret = 0
+        if self.ignore_group_sparsity:
+            return ret
+
         for feature in self.features[1:]:
             ret = ret + feature.conv.weight.pow(2).sum(3, keepdim=True).sum(2, keepdim=True).sqrt().mean()
         return ret / ((self.num_layers - 1) if self.num_layers > 1 else 1)
