@@ -1,9 +1,11 @@
 import warnings
+
 import numpy as np
 import torch
 from torch import nn
 from torch.nn import Parameter
 from torch.nn import functional as F
+
 from .base import ConfigurationError, Readout
 
 
@@ -144,7 +146,7 @@ class Gaussian2d(Readout):
     def regularizer(self, reduction="sum", average=None):
         return self.feature_l1(reduction=reduction, average=average) * self.feature_reg_weight
 
-    def forward(self, x, sample=None, shift=None, out_idx=None):
+    def forward(self, x, sample=None, shift=None, out_idx=None, **kwargs):
         """
         Propagates the input forwards through the readout
         Args:
@@ -403,9 +405,9 @@ class FullGaussian2d(Readout):
                            if sample is True/False, overrides the model_state (i.e training or eval) and does as instructed
         """
         with torch.no_grad():
-            self.mu.clamp_(min=-1, max=1)  # at eval time, only self.mu is used so it must belong to [-1,1]
-            if self.gauss_type != "full":
-                self.sigma.clamp_(min=0)  # sigma/variance i    s always a positive quantity
+            self.mu.clamp_(
+                min=-1, max=1
+            )  # at eval time, only self.mu is used so it must belong to [-1,1] # sigma/variance i    s always a positive quantity
 
         grid_shape = (batch_size,) + self.grid_shape[1:]
 
@@ -527,7 +529,7 @@ class FullGaussian2d(Readout):
         self.register_buffer("grid_sharing_index", torch.from_numpy(sharing_idx))
         self._shared_grid = True
 
-    def forward(self, x, sample=None, shift=None, out_idx=None):
+    def forward(self, x, sample=None, shift=None, out_idx=None, **kwargs):
         """
         Propagates the input forwards through the readout
         Args:
@@ -546,7 +548,7 @@ class FullGaussian2d(Readout):
         N, c, w, h = x.size()
         c_in, w_in, h_in = self.in_shape
         if (c_in, w_in, h_in) != (c, w, h):
-            raise ValueError("the specified feature map dimension is not the readout's expected input dimension")
+            warnings.warn("the specified feature map dimension is not the readout's expected input dimension")
         feat = self.features.view(1, c, self.outdims)
         bias = self.bias
         outdims = self.outdims
@@ -646,7 +648,7 @@ class RemappedGaussian2d(FullGaussian2d):
         super().initialize(mean_activity)
         self.initialize_remap_field()
 
-    def forward(self, x, sample=None, shift=None, out_idx=None):
+    def forward(self, x, sample=None, shift=None, out_idx=None, **kwargs):
         offset_field = self.remap_field(x) * self.max_remap_amplitude
 
         N, c, w, h = x.size()
@@ -783,7 +785,7 @@ class DeterministicGaussian2d(Readout):
             mu = self.mu + shift[None, ...]
         mean = mu.view(self.outdims, 1, 1, -1)
         pdf = self.grid - mean
-        pdf = torch.sum(pdf ** 2, dim=-1) / variances
+        pdf = torch.sum(pdf**2, dim=-1) / variances
         pdf = torch.exp(-0.5 * pdf)
         # normalize to sum=1
         pdf = pdf / torch.sum(pdf, dim=(1, 2), keepdim=True)
@@ -796,7 +798,7 @@ class DeterministicGaussian2d(Readout):
         if mean_activity is None:
             mean_activity = self.mean_activity
         self.mu.data.uniform_(-self.init_mu_range, self.init_mu_range)
-        self.log_var.data.fill_(np.log(self.init_sigma ** 2))
+        self.log_var.data.fill_(np.log(self.init_sigma**2))
         self.features.data.fill_(1 / self.in_shape[0])
         if self.bias is not None:
             self.initialize_bias(mean_activity=mean_activity)
@@ -825,7 +827,7 @@ class DeterministicGaussian2d(Readout):
             + self.variance_l1(reduction=reduction, average=average)
         ) * self.feature_reg_weight
 
-    def forward(self, x, shift=None, out_idx=None):
+    def forward(self, x, shift=None, out_idx=None, **kwargs):
         N, c, w, h = x.size()
         feat = self.features
 
@@ -995,7 +997,7 @@ class Gaussian3d(Readout):
             "The regularizer for this readout needs to be implemented! See issue https://github.com/sinzlab/neuralpredictors/issues/127"
         )
 
-    def forward(self, x, sample=None, shift=None, out_idx=None):
+    def forward(self, x, sample=None, shift=None, out_idx=None, **kwargs):
         """
         Propagates the input forwards through the readout
         Args:
@@ -1234,7 +1236,7 @@ class UltraSparse(Readout):
         if self.bias is not None:
             self.initialize_bias(mean_activity=mean_activity)
 
-    def forward(self, x, sample=True, shift=None, out_idx=None):
+    def forward(self, x, sample=True, shift=None, out_idx=None, **kwargs):
         """
         Propagates the input forwards through the readout
         Args:
